coastpy.stats package
=====================

Submodules
----------

coastpy.stats.metrics module
----------------------------

.. automodule:: coastpy.stats.metrics
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: coastpy.stats
   :members:
   :undoc-members:
   :show-inheritance:
